@@ -30,6 +30,7 @@
 #include <glade/glade.h>
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-exception.h>
+#include <gal/widgets/e-unicode.h>
 
 #include "Spell.h"
 #include "control.h"
@@ -88,10 +89,10 @@ clicked_replace (GtkWidget *w, SpellControlData *cd)
 	BonoboArg *arg;
 	gchar *replacement;
 
-	if (gtk_clist_get_text (GTK_CLIST (cd->clist_suggestions), cd->row, 0, &replacement)) {
-		/* printf ("set replace\n"); */
+	if ((replacement = gtk_clist_get_row_data (GTK_CLIST (cd->clist_suggestions), cd->row))) {
 		CORBA_Environment ev;
 
+		/* printf ("set replace\n"); */
 		CORBA_exception_init (&ev);
 		GNOME_Spell_Dictionary_setCorrection (cd->dict, cd->word, replacement, &ev);
 		CORBA_exception_free (&ev);
@@ -163,12 +164,16 @@ set_word (SpellControlData *cd, gchar *word)
 {
 	GNOME_Spell_StringSeq *seq;
 	CORBA_Environment ev;
-	gchar *str, *text [1];
+	gchar *str, *str_utf8, *text [1];
 	gint i;
 
-	str = g_strdup_printf ("Suggestions for '%s'", word);
-	gtk_label_set_text (GTK_LABEL (cd->label_word), str);
+	str_utf8 = e_utf8_from_locale_string (_("Suggestions for '%s'"));
+	str = g_strdup_printf (str_utf8, word);
+	g_free (str_utf8);
+	str_utf8 = e_utf8_to_gtk_string (cd->label_word, str);
+	gtk_label_set_text (GTK_LABEL (cd->label_word), str_utf8);
 	g_free (str);
+	g_free (str_utf8);
 
 	g_free (cd->word);
 	cd->word = g_strdup (word);
@@ -182,8 +187,11 @@ set_word (SpellControlData *cd, gchar *word)
 		gtk_clist_clear (GTK_CLIST (cd->clist_suggestions));
 		for (i = 0; i < seq->_length; i ++) {
 			/* printf ("\t%s\n", seq->_buffer [i]); */
-			text [0] = seq->_buffer [i];
+			text [0] = e_utf8_to_gtk_string (cd->clist_suggestions, seq->_buffer [i]);
 			gtk_clist_append (GTK_CLIST (cd->clist_suggestions), text);
+			gtk_clist_set_row_data_full (GTK_CLIST (cd->clist_suggestions), i,
+						     g_strdup (seq->_buffer [i]), g_free);
+			g_free (text [0]);
 		}
 		gtk_clist_select_row (GTK_CLIST (cd->clist_suggestions), 0, 0);
 		gtk_clist_thaw (GTK_CLIST (cd->clist_suggestions));
@@ -273,7 +281,7 @@ spell_control_construct (BonoboControl *control, GtkWidget *table, GladeXML *xml
 
 	bonobo_property_bag_add (cd->pb, "word", PROP_SPELL_WORD, BONOBO_ARG_STRING, NULL,
 				 "checked word",  BONOBO_PROPERTY_WRITEABLE);
-	bonobo_property_bag_add (cd->pb, "language", PROP_SPELL_REPLACE, BONOBO_ARG_STRING, NULL,
+	bonobo_property_bag_add (cd->pb, "language", PROP_SPELL_LANGUAGE, BONOBO_ARG_STRING, NULL,
 				 "dictionary language", BONOBO_PROPERTY_WRITEABLE);
 
 	def = bonobo_arg_new (BONOBO_ARG_STRING);
@@ -306,6 +314,11 @@ spell_control_construct (BonoboControl *control, GtkWidget *table, GladeXML *xml
 	CORBA_exception_init (&ev);
 	GNOME_Spell_Dictionary__set_active (cd->dict, CORBA_TRUE, &ev);
 	CORBA_exception_free (&ev);
+
+	CORBA_exception_init (&ev);
+	GNOME_Spell_Dictionary_setTag (cd->dict, "encoding", "utf-8", &ev);
+	CORBA_exception_free (&ev);
+
 	set_language (cd, "en");
 }
 
