@@ -132,7 +132,12 @@ impl_gnome_spell_dictionary_check_word (PortableServer_Servant servant, const CO
 	GNOMESpellDictionary *dict = GNOME_SPELL_DICTIONARY (bonobo_object_from_servant (servant));
 	gint pspell_result;
 	CORBA_boolean result = CORBA_TRUE;
-									 
+
+	g_return_val_if_fail (word, result);
+
+	if (!strcmp (word, "Ximian"))
+		return result;
+
 	DICT_DEBUG (printf ("Dictionary check_word: %s\n", word));
 	update_manager (dict, ev);
 	if (dict->manager) {
@@ -153,6 +158,8 @@ impl_gnome_spell_dictionary_add_word_to_session (PortableServer_Servant servant,
 {
 	GNOMESpellDictionary *dict = GNOME_SPELL_DICTIONARY (bonobo_object_from_servant (servant));
 
+	g_return_if_fail (word);
+
 	DICT_DEBUG (printf ("Dictionary add_word_to_session: %s\n", word));
 	pspell_manager_add_to_session (dict->manager, word, strlen (word));
 }
@@ -163,6 +170,8 @@ impl_gnome_spell_dictionary_add_word_to_personal (PortableServer_Servant servant
 {
 	GNOMESpellDictionary *dict = GNOME_SPELL_DICTIONARY (bonobo_object_from_servant (servant));
 
+	g_return_if_fail (word);
+
 	DICT_DEBUG (printf ("Dictionary add_word_to_personal: %s\n", word));
 	pspell_manager_add_to_personal (dict->manager, word, strlen (word));
 	pspell_manager_save_all_word_lists (dict->manager);
@@ -174,6 +183,9 @@ impl_gnome_spell_dictionary_set_correction (PortableServer_Servant servant,
 {
 	GNOMESpellDictionary *dict = GNOME_SPELL_DICTIONARY (bonobo_object_from_servant (servant));
 
+	g_return_if_fail (word);
+	g_return_if_fail (replacement);
+
 	DICT_DEBUG (printf ("Dictionary correction: %s <-- %s\n", word, replacement));
 	pspell_manager_store_replacement (dict->manager, word, strlen (word), replacement, strlen (replacement));
 	pspell_manager_save_all_word_lists (dict->manager);
@@ -188,8 +200,10 @@ impl_gnome_spell_dictionary_get_suggestions (PortableServer_Servant servant,
 	PspellStringEmulation *elements;
 	GNOME_Spell_StringSeq *seq = NULL;
 	gint i;
-	DICT_DEBUG (printf ("Dictionary correction: %s\n", word));
 
+	g_return_if_fail (word);
+
+	DICT_DEBUG (printf ("Dictionary correction: %s\n", word));
 	update_manager (dict, ev);
 	if (dict->manager) {
 		suggestions  = pspell_manager_suggest (dict->manager, word, strlen (word));
